package me.teridax.jcash.banking;

/**
 * Groups an owner and all of its accounts registered at a specific bank together.
 * The profile is oriented around a primary account of the owner.
 * This class is meant to be a read only reference for easier runtime processing of
 * data packed into nested structure of objects.
 */
public class Profile {

    private final Owner owner;
    private final Bank bank;
    private Account primaryAccount;
    private final Account[] accounts;

    public Profile(Owner owner, Bank bank, Account account, Account[] accounts) {
        this.owner = owner;
        this.bank = bank;
        this.accounts = accounts;
        this.primaryAccount = account;
    }

    public Account getPrimaryAccount() {
        return primaryAccount;
    }

    public Owner getOwner() {
        return owner;
    }

    public Bank getBank() {
        return bank;
    }

    public Account[] getAccounts() {
        return accounts;
    }

    /**
     * Set the primary account of this profile based on a descriptive text.
     * This method may not change anything if no account can be found with a matching description
     * @param description the description to find a matching account for
     */
    public void setPrimaryAccount(String description) {
        for (Account account : accounts) {
            if (account.getDescription().equals(description)) {
                this.primaryAccount = account;
                break;
            }
        }
    }
}
